"""Config YAML specification classes."""

from __future__ import annotations

from bitfount.runners.config_schemas.algorithm_schemas import (
    AggregatorConfig,
    AlgorithmConfig,
    CSVReportAlgorithmArgumentsConfig,
    CSVReportAlgorithmConfig,
    CSVReportGeneratorOphthalmologyAlgorithmArgumentsConfig,
    CSVReportGeneratorOphthalmologyAlgorithmConfig,
    ETDRSAlgorithmArgumentsConfig,
    ETDRSAlgorithmConfig,
    FederatedModelTrainingAlgorithmConfig,
    FederatedModelTrainingArgumentsConfig,
    FoveaCoordinatesAlgorithmArgumentsConfig,
    FoveaCoordinatesAlgorithmConfig,
    GATrialCalculationAlgorithmBronzeArgumentsConfig,
    GATrialCalculationAlgorithmBronzeConfig,
    GATrialCalculationAlgorithmJadeArgumentsConfig,
    GATrialCalculationAlgorithmJadeConfig,
    GATrialPDFGeneratorAlgorithmAmethystArgumentsConfig,
    GATrialPDFGeneratorAlgorithmAmethystConfig,
    GATrialPDFGeneratorAlgorithmJadeArgumentsConfig,
    GATrialPDFGeneratorAlgorithmJadeConfig,
    GenericAlgorithmConfig,
    HuggingFaceImageClassificationInferenceAlgorithmConfig,
    HuggingFaceImageClassificationInferenceArgumentsConfig,
    HuggingFaceImageSegmentationInferenceAlgorithmConfig,
    HuggingFaceImageSegmentationInferenceArgumentsConfig,
    HuggingFacePerplexityEvaluationAlgorithmConfig,
    HuggingFacePerplexityEvaluationArgumentsConfig,
    HuggingFaceTextClassificationInferenceAlgorithmConfig,
    HuggingFaceTextClassificationInferenceArgumentsConfig,
    HuggingFaceTextGenerationInferenceAlgorithmConfig,
    HuggingFaceTextGenerationInferenceArgumentsConfig,
    ModelAlgorithmConfig,
    ModelEvaluationAlgorithmConfig,
    ModelEvaluationArgumentsConfig,
    ModelInferenceAlgorithmConfig,
    ModelInferenceArgumentsConfig,
    ModelTrainingAndEvaluationAlgorithmConfig,
    ModelTrainingAndEvaluationArgumentsConfig,
    NextGenPatientQueryAlgorithmConfig,
    NextGenPatientQueryArgumentsConfig,
    PrivateSqlQueryAlgorithmConfig,
    PrivateSqlQueryArgumentsConfig,
    PrivateSqlQueryColumnArgumentsConfig,
    RecordFilterAlgorithmArgumentsConfig,
    RecordFilterAlgorithmConfig,
    SqlQueryAlgorithmConfig,
    SqlQueryArgumentsConfig,
    TIMMFineTuningAlgorithmConfig,
    TIMMFineTuningArgumentsConfig,
    TIMMInferenceAlgorithmConfig,
    TIMMInferenceArgumentsConfig,
    TrialInclusionCriteriaMatchAlgorithmAmethystArgumentsConfig,
    TrialInclusionCriteriaMatchAlgorithmAmethystConfig,
    TrialInclusionCriteriaMatchAlgorithmBronzeArgumentsConfig,
    TrialInclusionCriteriaMatchAlgorithmBronzeConfig,
    TrialInclusionCriteriaMatchAlgorithmJadeArgumentsConfig,
    TrialInclusionCriteriaMatchAlgorithmJadeConfig,
    _SimpleCSVAlgorithmAlgorithmConfig,
    _SimpleCSVAlgorithmArgumentsConfig,
)
from bitfount.runners.config_schemas.common_schemas import DataSplitConfig, PathConfig
from bitfount.runners.config_schemas.hub_schemas import (
    JWT,
    AccessManagerConfig,
    APIKeys,
    HubConfig,
)
from bitfount.runners.config_schemas.model_schemas import (
    BitfountModelReferenceConfig,
    ModelConfig,
    ModelStructureConfig,
)
from bitfount.runners.config_schemas.modeller_schemas import (
    DataStructureAssignConfig,
    DataStructureConfig,
    DataStructureSelectConfig,
    DataStructureTableConfig,
    DataStructureTransformConfig,
    ModellerConfig,
    ModellerUserConfig,
    PodsConfig,
    TaskConfig,
    TemplatedModellerConfig,
)
from bitfount.runners.config_schemas.pod_schemas import (
    DatasourceConfig,
    FileSystemFilterConfig,
    PodConfig,
    PodDataConfig,
    PodDbConfig,
    PodDetailsConfig,
)
from bitfount.runners.config_schemas.protocol_schemas import (
    FederatedAveragingProtocolArgumentsConfig,
    FederatedAveragingProtocolConfig,
    GAScreeningProtocolAmethystArgumentsConfig,
    GAScreeningProtocolAmethystConfig,
    GAScreeningProtocolBronzeArgumentsConfig,
    GAScreeningProtocolBronzeConfig,
    GAScreeningProtocolJadeArgumentsConfig,
    GAScreeningProtocolJadeConfig,
    GenericProtocolConfig,
    InferenceAndCSVReportArgumentsConfig,
    InferenceAndCSVReportConfig,
    InferenceAndReturnCSVReportArgumentsConfig,
    InferenceAndReturnCSVReportConfig,
    InstrumentedInferenceAndCSVReportArgumentsConfig,
    InstrumentedInferenceAndCSVReportConfig,
    NextGenSearchProtocolArgumentsConfig,
    NextGenSearchProtocolConfig,
    ProtocolConfig,
    ResultsOnlyProtocolArgumentsConfig,
    ResultsOnlyProtocolConfig,
    RetinalDiseaseProtocolCobaltArgumentsConfig,
    RetinalDiseaseProtocolCobaltConfig,
)

from .utils import _deserialize_model_ref, _deserialize_path

__all__ = [
    # algorithm_schemas
    "AggregatorConfig",
    "AlgorithmConfig",
    "CSVReportAlgorithmArgumentsConfig",
    "CSVReportAlgorithmConfig",
    "CSVReportGeneratorOphthalmologyAlgorithmArgumentsConfig",
    "CSVReportGeneratorOphthalmologyAlgorithmConfig",
    "ETDRSAlgorithmArgumentsConfig",
    "ETDRSAlgorithmConfig",
    "FederatedModelTrainingAlgorithmConfig",
    "FederatedModelTrainingArgumentsConfig",
    "FoveaCoordinatesAlgorithmArgumentsConfig",
    "FoveaCoordinatesAlgorithmConfig",
    "GATrialCalculationAlgorithmBronzeArgumentsConfig",
    "GATrialCalculationAlgorithmBronzeConfig",
    "GATrialCalculationAlgorithmJadeArgumentsConfig",
    "GATrialCalculationAlgorithmJadeConfig",
    "GATrialPDFGeneratorAlgorithmAmethystArgumentsConfig",
    "GATrialPDFGeneratorAlgorithmAmethystConfig",
    "GATrialPDFGeneratorAlgorithmJadeArgumentsConfig",
    "GATrialPDFGeneratorAlgorithmJadeConfig",
    "GenericAlgorithmConfig",
    "HuggingFaceImageClassificationInferenceAlgorithmConfig",
    "HuggingFaceImageClassificationInferenceArgumentsConfig",
    "HuggingFaceImageSegmentationInferenceAlgorithmConfig",
    "HuggingFaceImageSegmentationInferenceArgumentsConfig",
    "HuggingFacePerplexityEvaluationAlgorithmConfig",
    "HuggingFacePerplexityEvaluationArgumentsConfig",
    "HuggingFaceTextClassificationInferenceAlgorithmConfig",
    "HuggingFaceTextClassificationInferenceArgumentsConfig",
    "HuggingFaceTextGenerationInferenceAlgorithmConfig",
    "HuggingFaceTextGenerationInferenceArgumentsConfig",
    "ModelAlgorithmConfig",
    "ModelEvaluationAlgorithmConfig",
    "ModelEvaluationArgumentsConfig",
    "ModelInferenceAlgorithmConfig",
    "ModelInferenceArgumentsConfig",
    "ModelTrainingAndEvaluationAlgorithmConfig",
    "ModelTrainingAndEvaluationArgumentsConfig",
    "NextGenPatientQueryAlgorithmConfig",
    "NextGenPatientQueryArgumentsConfig",
    "PrivateSqlQueryAlgorithmConfig",
    "PrivateSqlQueryArgumentsConfig",
    "PrivateSqlQueryColumnArgumentsConfig",
    "RecordFilterAlgorithmArgumentsConfig",
    "RecordFilterAlgorithmConfig",
    "SqlQueryAlgorithmConfig",
    "SqlQueryArgumentsConfig",
    "TIMMFineTuningAlgorithmConfig",
    "TIMMFineTuningArgumentsConfig",
    "TIMMInferenceAlgorithmConfig",
    "TIMMInferenceArgumentsConfig",
    "TrialInclusionCriteriaMatchAlgorithmAmethystArgumentsConfig",
    "TrialInclusionCriteriaMatchAlgorithmAmethystConfig",
    "TrialInclusionCriteriaMatchAlgorithmBronzeArgumentsConfig",
    "TrialInclusionCriteriaMatchAlgorithmBronzeConfig",
    "TrialInclusionCriteriaMatchAlgorithmJadeArgumentsConfig",
    "TrialInclusionCriteriaMatchAlgorithmJadeConfig",
    "_SimpleCSVAlgorithmAlgorithmConfig",
    "_SimpleCSVAlgorithmArgumentsConfig",
    # common_schemas
    "DataSplitConfig",
    "PathConfig",
    # hub_schemas
    "JWT",
    "AccessManagerConfig",
    "APIKeys",
    "HubConfig",
    # model_schemas
    "BitfountModelReferenceConfig",
    "ModelConfig",
    "ModelStructureConfig",
    # modeller_schemas
    "DataStructureAssignConfig",
    "DataStructureConfig",
    "DataStructureSelectConfig",
    "DataStructureTableConfig",
    "DataStructureTransformConfig",
    "ModellerConfig",
    "ModellerUserConfig",
    "PodsConfig",
    "TaskConfig",
    "TemplatedModellerConfig",
    # pod_schemas
    "DatasourceConfig",
    "FileSystemFilterConfig",
    "PodConfig",
    "PodDataConfig",
    "PodDbConfig",
    "PodDetailsConfig",
    # protocol_schemas
    "FederatedAveragingProtocolArgumentsConfig",
    "FederatedAveragingProtocolConfig",
    "GAScreeningProtocolAmethystArgumentsConfig",
    "GAScreeningProtocolAmethystConfig",
    "GAScreeningProtocolBronzeArgumentsConfig",
    "GAScreeningProtocolBronzeConfig",
    "GAScreeningProtocolJadeArgumentsConfig",
    "GAScreeningProtocolJadeConfig",
    "GenericProtocolConfig",
    "InferenceAndCSVReportArgumentsConfig",
    "InferenceAndCSVReportConfig",
    "InferenceAndReturnCSVReportArgumentsConfig",
    "InferenceAndReturnCSVReportConfig",
    "InstrumentedInferenceAndCSVReportArgumentsConfig",
    "InstrumentedInferenceAndCSVReportConfig",
    "NextGenSearchProtocolArgumentsConfig",
    "NextGenSearchProtocolConfig",
    "ProtocolConfig",
    "ResultsOnlyProtocolArgumentsConfig",
    "ResultsOnlyProtocolConfig",
    "RetinalDiseaseProtocolCobaltArgumentsConfig",
    "RetinalDiseaseProtocolCobaltConfig",
    # utils
    "_deserialize_model_ref",
    "_deserialize_path",
]
